test_that("multi_logrank works", {
  T1 <- c(6, 6, 6, 6, 7, 9, 10, 10, 11, 13, 16, 17, 19, 20, 22, 23, 25, 32, 32, 34, 35)
  E1 <- c(1, 1, 1, 0, 1, 0, 1, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0)
  T2 <- c(1, 1, 2, 2, 3, 4, 4, 5, 5, 8, 8, 8, 8, 11, 11, 12, 12, 15, 17, 22, 23)
  E2 <- c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
  t1s<-list(T1, T1, T1)
  e1s<-list(E1, E1, E1)
  t2s<-list(T2, T2, T2)
  e2s<-list(E2, E2, E2)
  expect_equal(multi_logrank_test(t1s,t2s,e1s,e2s), rep(list(c(1.679294e+01,-4.097919e+00,4.168809e-05)),3), tolerance=1e-5)
})
